@@ -1,5 +1,3 @@
-import os
-
 """
 Module pyroutes.settings
 Used for importing settings, and defining default settings
@@ -8,6 +6,8 @@ Override per project settings in pyroutes_settings.py in
 your project folder
 """
 
+import os
+
 # Default template dir, relative to this imported __file__
 BUILTIN_TEMPLATES_DIR = os.path.join(
     os.path.dirname(__file__),
@@ -30,6 +30,8 @@ TEMPLATE_DIR = None # /foo/bar/templates/
 # Middleware
 MIDDLEWARE = (
     'pyroutes.middleware.errors.NotFoundMiddleware',
+    #'pyroutes.middleware.appendslash.AppendSlashes',
+    'pyroutes.middleware.responsify.Responsify',
     'pyroutes.middleware.errors.ErrorHandlerMiddleware',
 )
 
@@ -38,3 +40,9 @@ try:
     from pyroutes_settings import *
 except ImportError:
     pass
+
+try:
+    # This is done in case the key is given as unicode data.
+    SECRET_KEY = SECRET_KEY.encode('iso-8859-1')
+except AttributeError:
+    pass
