@@ -1,8 +1,12 @@
 #!/usr/bin/env python
 # encoding: utf-8
+
 """
+This module holds wrappers for xmltemplate, and xmltemplate itself.
 """
+
 import os
+import sys
 from pyroutes.template import xmltemplate
 from pyroutes import settings
 
@@ -23,13 +27,16 @@ class TemplateRenderer(object):
             template_dir=None):
         """
         Takes three parameters.
-        - ``base_template``: The base template. Usually with the html headers, css, etc.
-        - ``inclusion_param``: The <t:id=".."/> id which will be replaced with the content of the child template.
-        - ``template_dir``: Override the ``TEMPLATE_DIR`` setting from pyroutes.settings.
+        - ``base_template``: The base template. Usually with the html headers,
+                             css, etc.
+        - ``inclusion_param``: The <t:id=".."/> id which will be replaced with
+                               the content of the child template.
+        - ``template_dir``: Override the ``TEMPLATE_DIR`` setting from
+                            pyroutes.settings.
         """
         self.base_template = base_template
         self.inclusion_param = inclusion_param
-        if template_dir != None:
+        if template_dir is not None:
             self.template_dir = template_dir
         elif settings.TEMPLATE_DIR:
             self.template_dir = settings.TEMPLATE_DIR
@@ -47,8 +54,8 @@ class TemplateRenderer(object):
                 os.path.join(self.template_dir, template), data, False)
             data[self.inclusion_param] = doc
             master = xmltemplate.process_file(
-                os.path.join(self.template_dir, self.base_template), data);
+                os.path.join(self.template_dir, self.base_template), data)
         else:
             master = xmltemplate.process_file(
                 os.path.join(self.template_dir, template), data)
-        return master.toxml().encode("utf-8")
+        return master.toxml()
