@@ -1,3 +1,9 @@
+"""
+This module holds handy utilities for development and debugging of pyroutes
+applications. The methods found here are _not_ meant for use in production
+environments, no guarantees are given for their stability or security.
+"""
+
 import datetime
 import mimetypes
 import posixpath
@@ -10,7 +16,6 @@ from pyroutes.http.response import Response, Redirect, Http403, Http404
 from pyroutes.contrib import autoreload
 
 from wsgiref.simple_server import make_server
-from wsgiref.util import FileWrapper
 
 def devserver(application, port=8001, address='0.0.0.0', auto_reload=True):
     """
@@ -28,6 +33,7 @@ def devserver(application, port=8001, address='0.0.0.0', auto_reload=True):
     """
 
     def server_thread():
+        "A small wrapper method for wsgiref.make_server().serve_forever()"
         httpd = make_server(address, port, application)
         print "Starting server on %s port %d..." % (address, port)
         httpd.serve_forever()
@@ -60,10 +66,7 @@ def fileserver(request, *path_list):
     if '..' in path_list:
         raise Http404
 
-    if hasattr(settings, 'DEV_MEDIA_BASE'):
-        path = os.path.join(settings.DEV_MEDIA_BASE, *path_list)
-    else:
-        path = os.path.join('.', *path_list)
+    path = os.path.join(getattr(settings, 'DEV_MEDIA_BASE', '.'), *path_list)
 
     if not os.path.exists(path):
         raise Http404
@@ -115,10 +118,17 @@ def fileserver(request, *path_list):
         )
 
     contenttype = mimetypes.guess_type(path)[0] or "application/octet-stream"
-    file_to_send = FileWrapper(open(path))
     size = os.path.getsize(path)
 
     headers.append(('Content-Type', contenttype))
     headers.append(('Content-Length', str(size)))
 
-    return Response(file_to_send, headers=headers)
+    def file_wrapper(iterable):
+        return iter(lambda: iterable.read(8192), '')
+    if 'wsgi.file_wrapper' in request.ENV:
+        file_wrapper = request.ENV['wsgi.file_wrapper']
+
+    fh = open(path, 'rb')
+    wrapped_file = file_wrapper(fh)
+
+    return Response(wrapped_file, headers=headers)
